@@ -35,6 +35,14 @@ class ArtLayer(Photoshop):
     def blendMode(self, mode):
         self.app.blendMode = mode
 
+    @property
+    def linkedLayers(self) -> list:
+        """Get all layers linked to this layer.
+
+        Returns:
+            list: Layer objects"""
+        return [ArtLayer(layer) for layer in self.app.linkedLayers]
+
     @property
     def name(self) -> str:
         return self.app.name
@@ -45,12 +53,12 @@ class ArtLayer(Photoshop):
 
     @property
     def fillOpacity(self):
-        """he interior opacity of the layer. Range: 0.0 to 100.0."""
+        """The interior opacity of the layer. Range: 0.0 to 100.0."""
         return self.app.fillOpacity
 
     @fillOpacity.setter
     def fillOpacity(self, value):
-        """he interior opacity of the layer. Range: 0.0 to 100.0."""
+        """The interior opacity of the layer. Range: 0.0 to 100.0."""
         self.app.fillOpacity = value
 
     @property
@@ -122,6 +130,15 @@ class ArtLayer(Photoshop):
     def layerMaskFeather(self, value):
         self.app.layerMaskFeather = value
 
+    @property
+    def opacity(self):
+        """The master opacity of the layer."""
+        return round(self.app.opacity)
+
+    @opacity.setter
+    def opacity(self, value):
+        self.app.opacity = value
+
     @property
     def parent(self):
         """The object’s container."""
@@ -158,7 +175,6 @@ class ArtLayer(Photoshop):
 
         returns:
             TextItem:
-
         """
         return TextItem(self.app.textItem)
 
@@ -443,8 +459,8 @@ class ArtLayer(Photoshop):
         self.app.applyPinch(amount)
 
     def remove(self):
-        layer = f'app.activeDocument.artLayers.getByName("{self.app.name}")'
-        self.eval_javascript(f"{layer}.remove()")
+        """Removes this layer from the document."""
+        self.app.delete()
 
     def rasterize(self, target: RasterizeType):
         self.app.rasterize(target)
@@ -461,8 +477,9 @@ class ArtLayer(Photoshop):
     def link(self, with_layer):
         self.app.link(with_layer)
 
-    def unlink(self, with_layer):
-        self.app.unlink(with_layer)
+    def unlink(self):
+        """Unlink this layer from any linked layers."""
+        self.app.unlink()
 
     def invert(self):
         self.app.invert()
